@@ -36,6 +36,9 @@
 #ifndef TARGET_RISCV_DEFAULT_ABI
 # define TARGET_RISCV_DEFAULT_ABI lp64d
 #endif
+#ifndef TARGET_DEFAULT_CMODEL
+# define TARGET_DEFAULT_CMODEL CM_MEDLOW
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
